//imports functions from D3 library
import { csv, select } from 'd3';

//imports the scatterPlot function from the scatterPlot.js file
import { scatterPlot } from './scatterPlot';

// This is the URL of my iris dataset
const csvUrl = [ 
  'https://gist.githubusercontent.com/',
  'kovvurisupraj/', // User
  'dc2fc326efda4c4a956eece7d16bc583/', // Id of the Gist
  'raw/d01c9d3ce6383e7463dbe37024f263ad891591ab/', // commit
  'iris.csv', // File name
].join('');

//  function used to parse each row of the loaded csv file
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

// To set width and height of the svg element to the size of the window
const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

//  function which loads the csv data and creates the scatter plot
const main = async () => {
  
  
  //invoking svg elements
  svg.call(
    
    // The scatter plot using the scatterPlot function and the csv data
    scatterPlot()
      .width(width)
      .height(height)
      .data(await csv(csvUrl, parseRow))
      .xValue((d) => d.petal_width)
      .yValue((d) => d.sepal_length)
      .symbolValue((d) => d.species)
      .margin({
        top: 20,
        right: 20,
        bottom: 100,
        left: 100,
      })
      .size(100)
  );
 
  // text label for the y axis
  svg.append("text")   
        .attr("transform", "rotate(-90)")
        .attr("x", 0 - (height/2) )
        .attr("dy", "1em")
        .style("text-anchor", "middle")
        .text("petal width")
        .attr("font-weight","bold");
      
  	svg.append('g')
			.attr('transform',
      `translate(0,
      ${height-margin.bottom})`)
			.call(axisBottom(x))
        .attr("font-family","cursive");
  // text label for the x axis
  	svg.append("text")
        .attr("x", width / 2 )
        .attr("y",  450)
        .style("text-anchor", "middle")
        .text("sepal length")
        .attr("font-weight","bold");
                
    svg.append('text')
        .attr('class','axis-label')
        .attr('x',innerWidth/2.0)
        .attr('y',50)
        .style("font","30px times")
        .text("Scatter Plot")
                
};
// calls the main function to start the program
main();
